Settings

View Hub details like Platform Version, Hardware version, IP Address and more.

Hub Details

Setup and Configure Local Hub Login Security

Hub Login Security
lock

View and change your location information and modes.

Location and Modes

View your Z-Wave devices and control the radio.

Z-Wave Details

View your Zigbee devices and control the radio.

Zigbee Details

Check for updates and install the latest software.

Check for Updates

Restart your hub safely.

Reboot Hub

Shutdown your hub safely.

Shutdown Hub

Download backups of your hub's database and restore as needed.

Backup and Restore

View Hub Registration Information

Hub Registration

## Hub Details